balls

package
v0.1.18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 7, 2026 License: BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Config

func Config(b tree.Node)

Types

type Balls

type Balls struct {

	// Number of balls: if collide, then run out of memory above 1000 or so
	NBalls int

	// Collide is whether the balls collide with each other
	Collide bool

	// Size of each ball (m)
	Size float32

	// Mass of each ball (kg)
	Mass float32

	// size of the box (m)
	Width  float32
	Depth  float32
	Height float32
	Thick  float32

	Bounce          float32
	Friction        float32
	FrictionTortion float32
	FrictionRolling float32
}

Balls has sim params

func (*Balls) Defaults

func (b *Balls) Defaults()

Directories

Path Synopsis

Jump to