Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Balls ¶
type Balls struct {
// Number of balls: if collide, then run out of memory above 1000 or so
NBalls int
// Collide is whether the balls collide with each other
Collide bool
// Size of each ball (m)
Size float32
// Mass of each ball (kg)
Mass float32
// size of the box (m)
Width float32
Depth float32
Height float32
Thick float32
Bounce float32
Friction float32
FrictionTortion float32
FrictionRolling float32
}
Balls has sim params
Click to show internal directories.
Click to hide internal directories.